==> config_entity_cloner-1.0.1.tar.gz: config_entity_cloner/src/Plugin/config_entity_cloner/ConfigEntityClonerProcess/SimpleSitemapConfigEntityClonerProcess.php <==
<?php

namespace Drupal\config_entity_cloner\Plugin\config_entity_cloner\ConfigEntityClonerProcess;

use Drupal\config_entity_cloner\PluginManager\ConfigEntityClonerProcess\ConfigEntityClonerProcessInterface;
use Drupal\config_entity_cloner\Service\ConfigEntityCloner;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityInterface;
use Psr\Log\LoggerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation For the type processor.
 *
 * @ConfigEntityClonerProcessAnnotation(
 *   id = "simple_site_map",
 *   label = "Simple SiteMap",
 *   weight = 30
 * )
 */
class SimpleSitemapConfigEntityClonerProcess implements ConfigEntityClonerProcessInterface {

  /**
   * Logger.
   *
   * @var \Psr\Log\LoggerInterface
   */
  private LoggerInterface $logger;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  private ConfigFactoryInterface $configFactory;

  /**
   * SimpleSiteMapCloneProcess constructor.
   *
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   THe config factory.
   */
  public function __construct(LoggerInterface $logger, ConfigFactoryInterface $configFactory) {
    $this->logger = $logger;
    $this->configFactory = $configFactory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): ConfigEntityClonerProcessInterface {
    return new static(
      $container->get('logger.factory')->get(ConfigEntityCloner::SERVICE_NAME),
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function cloneProcess(EntityInterface $newEntity, EntityInterface $originalEntity): void {
    if ($simpleSiteMapGenerator = \Drupal::service('simple_sitemap.generator')) {
      if ($data = $simpleSiteMapGenerator->getBundleSettings($originalEntity->getEntityType()
        ->getBundleOf(), $originalEntity->id())) {
        $simpleSiteMapGenerator->setBundleSettings($newEntity->getEntityType()
          ->getBundleOf(), $newEntity->id(), $data);
      }
    }
  }

}

==> config_entity_cloner-1.0.3-rc2.tar.gz: config_entity_cloner/src/Plugin/config_entity_cloner/ConfigEntityClonerProcess/SimpleSitemapConfigEntityClonerProcess.php <==
<?php

namespace Drupal\config_entity_cloner\Plugin\config_entity_cloner\ConfigEntityClonerProcess;

use Drupal\config_entity_cloner\PluginManager\ConfigEntityClonerProcess\ConfigEntityClonerProcessInterface;
use Drupal\config_entity_cloner\Service\ConfigEntityCloner;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityInterface;
use Psr\Log\LoggerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation For the type processor.
 *
 * @ConfigEntityClonerProcessAnnotation(
 *   id = "simple_site_map",
 *   label = "Simple SiteMap",
 *   weight = 30
 * )
 */
class SimpleSitemapConfigEntityClonerProcess implements ConfigEntityClonerProcessInterface {

  /**
   * Logger.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * SimpleSiteMapCloneProcess constructor.
   *
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   THe config factory.
   */
  public function __construct(LoggerInterface $logger, ConfigFactoryInterface $configFactory) {
    $this->logger = $logger;
    $this->configFactory = $configFactory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): ConfigEntityClonerProcessInterface {
    return new static(
      $container->get('logger.factory')->get(ConfigEntityCloner::SERVICE_NAME),
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function cloneProcess(EntityInterface $newEntity, EntityInterface $originalEntity): void {
    if ($simpleSiteMapGenerator = \Drupal::service('simple_sitemap.generator')) {
      if ($data = $simpleSiteMapGenerator->getBundleSettings($originalEntity->getEntityType()
        ->getBundleOf(), $originalEntity->id())) {
        $simpleSiteMapGenerator->setBundleSettings($newEntity->getEntityType()
          ->getBundleOf(), $newEntity->id(), $data);
      }
    }
  }

}
